pygeodesy.geodesicw.GeodesicLine

Package pygeodesy :: Module geodesicw :: Class GeodesicLine |
[frames] | no frames]

# Class GeodesicLine

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
        karney._CapsBase --+
                           |
            karney._kWrapped --+
                               |
                       _gWrapped --+
                                   |
                                  GeodesicLine

Wrapper around Karney's class geographiclib.geodesicline.GeodesicLine.

Instance Methods
Inherited from `karney._CapsBase`: `caps_` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr`, `toStr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Static Methods
a new object with type S, a subtype of T |
__new__(unused, geodesic, lat1, lon1, azi1, caps=3979, **name) Return a wrapped `geodesicline.GeodesicLine` instance from Karney's Python geographiclib, provided the latter is installed, otherwise an `ImportError`. |

Class Variables
Inherited from `karney._CapsBase`: `ALL`, `AREA`, `AZIMUTH`, `DISTANCE`, `DISTANCE_IN`, `EMPTY`, `GEODESICSCALE`, `LATITUDE`, `LINE_CAPS`, `LINE_OFF`, `LONGITUDE`, `LONG_UNROLL`, `NONFINITONAN`, `REDUCEDLENGTH`, `STANDARD`, `STANDARD_LINE`

Properties
Inherited from `_gWrapped`: `Geodesic`, `GeodesicLine`, `Geodesic_WGS84` Inherited from `karney._kWrapped`: `Math`, `Math_K_2`, `geographiclib` Inherited from `karney._CapsBase`: `caps`, `debug` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __new__ (unused, geodesic, lat1, lon1, azi1, caps=3979, **name) Static Method |
Return a wrapped `geodesicline.GeodesicLine` instance from Karney's Python geographiclib, provided the latter is installed, otherwise an `ImportError`. Arguments: `geodesic` - A wrapped Geodesic instance. `lat1` - Latitude of the first points (`degrees`). `lon1` - Longitude of the first points (`degrees`). `azi1` - Azimuth at the first points (compass `degrees360`). `caps` - Optional, bit-or'ed combination of Caps values specifying the capabilities the `GeodesicLine` instance should possess, i.e., which quantities can be returned by methods `GeodesicLine.Position` and `GeodesicLine.ArcPosition`. `name` - Optional `name=NN` (`str`). Returns: a new object with type S, a subtype of T Overrides: object.__new__